==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/mixins/block/SnowPackingMixin.java <==
package com.github.thedeathlycow.frostiful.mixins.block;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.block.PackedSnowBlock;
import com.github.thedeathlycow.frostiful.registry.FBlocks;
import com.github.thedeathlycow.frostiful.registry.tag.FEntityTypeTags;
import net.minecraft.class_1297;
import net.minecraft.class_1928;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2488;
import net.minecraft.class_2680;
import net.minecraft.class_3417;
import net.minecraft.class_4970;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_4970.class)
public abstract class SnowPackingMixin {

    @Inject(
            method = "entityInside",
            at = @At("TAIL")
    )
    private void smushSnowWhenSteppedOnByHeavyEntity(class_2680 state, class_1937 world, class_2338 pos, class_1297 entity, CallbackInfo ci) {

        boolean maySmushSnow = state.method_26204() == class_2246.field_10477
                && entity.method_5864().method_20210(FEntityTypeTags.HEAVY_ENTITY_TYPES)
                && !world.field_9236
                && Frostiful.getConfig().freezingConfig.doSnowPacking()
                && world.method_8450().method_8355(class_1928.field_19388)
                && isEntityWalkingOn(pos, entity);

        if (maySmushSnow) {

            int layers = state.method_11654(class_2488.field_11518);

            class_2680 packedSnow = FBlocks.PACKED_SNOW.method_9564()
                    .method_11657(PackedSnowBlock.LAYERS, layers);

            world.method_8501(pos, packedSnow);
            entity.method_5783(class_3417.field_14945, 1.0f, 1.0f);
        }
    }

    private static boolean isEntityWalkingOn(class_2338 pos, class_1297 entity) {
        return entity.method_24828() && entity.method_24515().equals(pos);
    }

}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/mixins/block/SnowPackingMixin.java <==
package com.github.thedeathlycow.frostiful.mixins.block;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.block.PackedSnowBlock;
import com.github.thedeathlycow.frostiful.registry.FBlocks;
import com.github.thedeathlycow.frostiful.registry.tag.FEntityTypeTags;
import net.minecraft.class_10774;
import net.minecraft.class_1297;
import net.minecraft.class_1928;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2488;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_4970;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_4970.class)
public abstract class SnowPackingMixin {

    @Inject(
            method = "onEntityCollision",
            at = @At("TAIL")
    )
    private void smushSnowWhenSteppedOnByHeavyEntity(class_2680 state, class_1937 world, class_2338 pos, class_1297 entity, class_10774 handler, CallbackInfo ci) {
        boolean maySmushSnow = state.method_26204() == class_2246.field_10477
                && entity.method_5864().method_20210(FEntityTypeTags.HEAVY_ENTITY_TYPES)
                && !world.field_9236
                && Frostiful.getConfig().freezingConfig.doSnowPacking()
                && ((class_3218) world).method_64395().method_8355(class_1928.field_19388)
                && isEntityWalkingOn(pos, entity);

        if (maySmushSnow) {

            int layers = state.method_11654(class_2488.field_11518);

            class_2680 packedSnow = FBlocks.PACKED_SNOW.method_9564()
                    .method_11657(PackedSnowBlock.LAYERS, layers);

            world.method_8501(pos, packedSnow);
            entity.method_5783(class_3417.field_14945, 1.0f, 1.0f);
        }
    }

    private static boolean isEntityWalkingOn(class_2338 pos, class_1297 entity) {
        return entity.method_24828() && entity.method_24515().equals(pos);
    }

}
